package weather;

import weather.selector.Selector;


/**
 * A class to hold the current plotting parameters which are
 * set by the controller and used by the plotting panel.
 * Only the controller should update these values.
 */
public class PlotParameters
{
	/**
	 * The report the plot is for.
	 */
	public Report mReport;

	public ObservationList mFullObservationList;
	public ObservationList mViewedObservationList;
	public ObservationList mObservationList1;
	public ObservationList mObservationList2;

	/**
	 * The observation which is currently selected, or null,
	 * and whether that observation is for the first plot.
	 */
	public Observation mSelectedObservation;
	public boolean mSelectedIsPlot1;

	//
	// The first and (optional) second selector for the plot.
	//
	public Selector mSelector1;
	public Selector mSelector2;

	//
	// The major and minor time intervals for the plot in minutes.
	// These values are calculated from the size of the time interval.
	//
	public int mTimeMajorInterval;
	public int mTimeMinorInterval;

	//
	// The minimum and maximum times for the plot.
	// These aren't the same as the times of the first or last observations
	// since rounding to the major time interval is done and there may
	// be gaps in the observations.
	//
	public DateTime mMinimumTime;
	public DateTime mMaximumTime;

	/**
	 * The observation if any to draw marker lines for.
	 * This is null if no marker lines are to be shown.
	 */
	public Observation mMarkerObservation;

	/**
	 * The shift value for the plot.
	 * This is the number of hours to shift the view leftwards by.
	 * The value should be a multiple of the major time interval.
	 * This is ignored if only the currently collected report is shown.
	 */
	public int mShiftHours;

	/**
	 * The maximum time difference in milliseconds between the
	 * first and last observation to show.  A value of zero indicates
	 * that only the currently collected report is to be shown.
	 * A value of MAX_VALUE indicates that all observations for the
	 * site are to be shown.
	 */
	public long mTimeInterval;

	/**
	 * The number of hours in an interval when displaying data in the
	 * grouping mode.  In this mode the maximum and minimum values
	 * are shown for each interval.  If this is zero then the normal plot is
	 * done.  Otherwise the value must either be an exact divisor of a
	 * day or else one of several special multiple-day intervals.
	 */
	public  int mGroupHours;

	/**
	 * Whether uniform scaling is being used.
	 */
	public  boolean mIsUniformScaling;

	/**
	 * Whether UTC times are shown.
	 */
	public boolean mIsShowUTCTimes;
}
