/**
 * Copyright (c) 2014 David I. Bell
 * Permission is granted to use, distribute, or modify this source,
 * provided that this copyright notice remains intact.
 */
package weather.selector;

import weather.DateTime;
import weather.Observation;
import weather.PlotParameters;


public class RainSelector extends Selector
{
	@Override
	public String getName()
	{
		return "Rain since 9am (mm)";
	}


	@Override
	public String getUnitsName()
	{
		return "mm";
	}


	@Override
	public Object getValue(Observation observation)
	{
		return observation.getRain();
	}


	@Override
	public ValueType getValueType()
	{
		return ValueType.RAINFALL;
	}


	@Override
	public double getMajorInterval(double range)
	{
		if (range <= 5)
			return 1;

		return 5;
	}


	@Override
	public double getMinorInterval(double range)
	{
		if (range <= 5)
			return 0.2;

		return 1;
	}


	@Override
	public boolean isMinorIntervalLabeled(double range)
	{
		return (range <= 30);
	}


	@Override
	public boolean isJoined(PlotParameters plotParameters,
		Observation first, Observation second)
	{
		if (!super.isJoined(plotParameters, first, second))
			return false;

		//
		// Check whether the 9:00 AM boundary is crossed.
		// This is when the rainfall value is reset to zero.
		//
		DateTime firstTime = first.getLocalTime();
		DateTime secondTime = second.getLocalTime();

		if ((firstTime.getMinutesIntoDay() <= 9 * 60) &&
			(secondTime.getMinutesIntoDay() > 9 * 60))
		{
			return false;
		}

		return true;
	}
}
